<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

class WC_Gateway_Pay3 extends WC_Payment_Gateway {

    public function __construct() {
        $this->id = 'pay3';
        $this->method_title = 'Pay3';
        $this->method_description = 'Custom Payment Gateway for Pay3.';
        $this->title = 'Pay3';
        $this->icon = plugin_dir_url( __FILE__ ) . '../assets/img/logo.png'; // Replace with your logo path.
        $this->has_fields = false; // No custom fields for now.
        
        // Load the settings
        $this->init_form_fields();
        $this->init_settings();

        // Save settings
        add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'process_admin_options' ) );
    }

    public function init_form_fields() {
        $this->form_fields = array(
            'enabled' => array(
                'title'   => 'Enable/Disable',
                'type'    => 'checkbox',
                'label'   => 'Enable Pay3 Payment',
                'default' => 'no'
            ),
            'title' => array(
                'title'       => 'Title',
                'type'        => 'text',
                'description' => 'This controls the title which the user sees during checkout.',
                'default'     => 'Pay3'
            ),
            'description' => array(
                'title'       => 'Description',
                'type'        => 'textarea',
                'description' => 'This controls the description which the user sees during checkout.',
                'default'     => 'Pay with Pay3 securely.'
            ),
        );
    }

    public function process_payment( $order_id ) {
        $order = wc_get_order( $order_id );

        // Send payment request to your API
        $response = $this->send_payment_request( $order );

        if ( $response->status === 'success' ) {
            // Payment successful, mark order as processing
            $order->payment_complete();
            $order->reduce_order_stock();

            // Return redirect URL for the user
            return array(
                'result'   => 'success',
                'redirect' => $response->payment_url,
            );
        } else {
            // Payment failed
            wc_add_notice( 'Payment failed. Please try again.', 'error' );
            return array(
                'result'   => 'failure',
                'redirect' => $this->get_return_url( $order ),
            );
        }
    }

    private function send_payment_request( $order ) {
        // Example API request to your server
        $api_url = 'https://yourapi.com/api/payment/make';
        $response = wp_remote_post( $api_url, array(
            'method'    => 'POST',
            'body'      => json_encode( array(
                'gateway'   => 'pay3',
                'amount'    => $order->get_total(),
                'callback'  => $this->get_return_url( $order ),
            ) ),
            'headers'   => array(
                'Content-Type' => 'application/json',
            ),
        ) );

        return json_decode( wp_remote_retrieve_body( $response ) );
    }
}
